@@ -1,10 +1,10 @@
 package Bundle::W3C::Validator;
 
-use 5.8.0;
+use 5.008;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.8.0';
+$VERSION = '0.8.5';
 
 1;
 
@@ -21,18 +21,30 @@ C<perl -MCPAN -e "install Bundle::W3C::Validator">
 =head1 CONTENTS
 
  CGI 2.81
- Config::General 2.19
+ CGI::Carp
+ Config::General 2.31
  Encode
+ Encode::Alias
  Encode::HanExtra
- Encode::JIS2K
- File::Spec
+ Encode::JIS2K - (optional)
+ File::Spec::Functions
  HTML::Encoding 0.52
- HTML::Parser 3.25
+ HTML::Parser 3.24
  HTML::Template 2.6
- LWP::UserAgent 1.90
+ HTML::Tidy - (optional)
+ HTTP::Headers::Auth
+ HTTP::Headers::Util
+ HTTP::Message
+ HTTP::Negotiate
+ HTTP::Request
+ LWP::UserAgent 2.032
  Net::IP
+ Net::hostent
  SGML::Parser::OpenSP
+ Socket
+ String::Approx
  URI
+ URI::Escape
  XML::LibXML
 
 =head1 DESCRIPTION
@@ -47,11 +59,11 @@ perl(1)
 
 =head1 AUTHOR
 
-The W3C Markup Validator Team, E<lt>www-validator@w3.orgE<gt>
+W3C QA-dev Team, E<lt>public-qa-dev@w3.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 1994-2007 World Wide Web Consortium, (Massachusetts
+Copyright (C) 1994-2009 World Wide Web Consortium, (Massachusetts
 Institute of Technology, European Research Consortium for Informatics
 and Mathematics, Keio University). All Rights Reserved. This work is
 distributed under the W3C(R) Software License [1] in the hope that it
